# == Class: domain_config
#
# Domain Config Class will add the server to the existing AD domain.
#
# === Parameters
#
# [*domainfqdd*]
#   Fully qualified domain name
#   e.g. "puppetlabs.lan"
#
# [*domainname*]
#   Domain name that is used to connect to the AD using format domainname/username
#   e.g. "puppetlabs"
#
# [*username*]
#   Username of domain user with machine join privileges.
#
# [*password*]
#   Password for domain user. ASM encryption string needs to be passed
#
# === Examples
#
#  class { windows_postinstall::domain::domain_membership:
#    domainfqdd        => 'pupetlabs.lan',
#    domainname        => 'puppetlabs',
#    username      => 'administrator',
#    password      => 'ASM Encryped Password',
#  }
#
class windows_postinstall::domain::domain_config (
  $domainfqdd,
  $domainname,
  $username,
  $password,
){

# Validate Parameters
  validate_string($username)
  validate_string($password)

  exec { 'join_domain':
    command   => template('windows_postinstall/domain_config.ps1.erb'),
    logoutput => true,
    unless   => "if((Get-WmiObject -Class Win32_ComputerSystem).domain -ne '${domainfqdd}'){ exit 1 }",
    provider  => powershell,
  }

  reboot { 'after':
    subscribe => Exec['join_domain'],
    apply     => finished,
  }

  file {'C:\ProgramData\PuppetLabs\Puppet\var\state\resources.txt':
    ensure => 'absent',
    require => 'Reboot[after]'
  }

}

