# == Class: windows_postinstall::nic::nic_ip_settings
#
# Create / configure the NIC team on the Windows server / VM.
#
# === Parameters
#
# [*ipaddress_info*]
#   IP Address information that needs to be configured. Input needs to be provided in below JSON format
#{
#  "NICIPInfo":
#    [
#      {
#         "adapter_name": "Team1",
#         "ip_address": "172.25.10.60",
#         "subnet": "255.255.0.0",
#         "gateway": "172.25.0.1",
#         "primaryDns": "172.20.0.8",
#         "dnsSuffix" : "asmdev.local",
#         "vlan_id": "25"
#      },
#
#      {
#         "adapter_name": "Team2",
#         "ip_address": "dhcp",
#         "subnet": "",
#         "gateway": "",
#         "primaryDns": "",
#         "dnsSuffix" : "asmdev.local",
#         "vlan_id": "22"
#
#      }
#  ]
#}

class windows_postinstall::nic::nic_ip_settings(
  $ipaddress_info  = undef,
) {
  if $::osfamily != 'Windows' {
    fail('This module is only for Windows')
  }

  # Validate Parameters
  validate_string($macaddress)

  exec { 'configure_ip_address':
    command   => template('windows_postinstall/nic_ip_settings.ps1.erb'),
    logoutput => true,
    provider  => powershell,
  }

}

