# == Class: windows_postinstall::nic::nic_team
#
# Create / configure the NIC team on the Windows server / VM.
#
# === Parameters
# [*nic_team_info*]
#   Infomation of NIC Teams and NIC Macaddress to be added to be NIC Team
#   {
#     "TeamInfo":
#     [
#       {
#         "TeamName"=> "Team1",
#         "TeamMembers"=> "aa-bb-cc-dd-ee-ff,aa-bb-cc-dd-ee-ff"
#
#       },
#       {
#         "TeamName" => "Team2",
#         "TeamMembers"=> "aa-bb-cc-dd-ee-ff,aa-bb-cc-dd-ee-ff"
#       }
#     ]
#   }
# [*nic_team_algorithm_name*]
#   NIC Team alogithm name. Default is "HyperVPort"
#
# [*nic_team_mode*]
#   Mode of NIC Team configruation. Default is "SwitchIndependent"
#
# === Examples
#  class { windows_postinstall::nic::nic_team:
#    nic_team_name             => 'nic-team1,nic-team2',
#    macaddress                => 'aa-aa-aa-aa-aa,bb-bb-bb-bb-bb-bb;cc-cc-cc-cc-cc-cc,dd-dd-dd-dd-dd-dd',
#    nic_team_algorithm_name   => 'HyperVPort',
#    nic_team_mode             => 'SwitchIndependent',
#  }

class windows_postinstall::nic::nic_team(
  $macaddress  = undef,
  $nic_team_name = undef,
  $nic_team_info = {},
  $nic_team_algorithm_name = 'HyperVPort',
  $nic_team_mode = 'SwitchIndependent'
) {
  if $::osfamily != 'Windows' {
    fail('This module is only for Windows')
  }

# Validate Parameters
  validate_string($nic_team_algorithm_name)
  validate_string($nic_team_mode)

  exec { 'configure_team':
    command   => template('windows_postinstall/nic_team.ps1.erb'),
    logoutput => true,
    provider  => powershell,
  }

}

